@@ -1,18 +1,17 @@
-from easy_notifyer.handlers import (
-    mailer_reporter,
-    telegram_reporter,
-)
+from easy_notifyer.exceptions import ConfigError
+from easy_notifyer.handlers import mailer_reporter, telegram_reporter
 from easy_notifyer.mailer import Mailer
 from easy_notifyer.telegram import Telegram, TelegramAsync
 
 
-__version__ = '0.0.4'
+__version__ = '0.1.0'
 
 
 __all__ = [
+    'ConfigError',
     "Mailer",
     "Telegram",
-    "TelegramAsync",
+    'TelegramAsync',
     "mailer_reporter",
     "telegram_reporter",
 ]
